==> poliscidata_1.2.0.tar.gz: poliscidata/R/available.imported.functions.r <==
##' @name available.imported.functions
##' @rdname available.imported.functions
##'
##' @title Imported Functions Made Available to Users
##' @param ... See source package help file for details on function usage.
##'
NULL

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{compmeans}} function is imported from descr package.  
##' See \code{\link[descr]{compmeans}} documentation for details.
compmeans <- function(...) { descr::compmeans(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{crosstab}} function is imported from the descr package.
##' See \code{\link[descr]{crosstab}} documentation for details.
crosstab <- function(...) { descr::crosstab(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{csv.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{csv.get}} documentation for details.
csv.get <- function(...) { Hmisc::csv.get(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{cut2}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{cut2}} documentation for details.
cut2 <- function(...) { Hmisc::cut2(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[plyr]{ddply}} function is imported from the plyr package.  
##' See \code{\link[plyr]{ddply}} documentation for details.
ddply <- function(...) { plyr::ddply(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{describe}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{describe}} documentation for details.
describe <- function(...) { Hmisc::describe(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{freq}} function is imported from the descr package. 
##' See \code{\link[descr]{freq}} documentation for details.
freq <- function(...) { descr::freq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[gplots]{plotmeans}} function is imported from the gplots package.  
##' See \code{\link[gplots]{plotmeans}} documentation for details.
plotmeans <- function(...) { gplots::plotmeans(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[car]{scatterplot}} function is imported from the car package.  
##' See \code{\link[car]{scatterplot}} documentation for details.
scatterplot <- function(...) { car::scatterplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{spss.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{spss.get}} documentation for details.
spss.get <- function(...) { Hmisc::spss.get(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{stata.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{stata.get}} documentation for details.
stata.get <- function(...) { Hmisc::stata.get(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyboxplot}} function is imported from the survey package.  
##' See \code{\link[survey]{svyboxplot}} documentation for details.
svyboxplot <- function(...) { survey::svyboxplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyby}} function is imported from the survey package.  
##' See \code{\link[survey]{svyby}} documentation for details.
svyby <- function(...) { survey::svyby(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svychisq}} function is imported from the survey package.  
##' See \code{\link[survey]{svychisq}} documentation for details.
svychisq <- function(...) { survey::svychisq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svydesign}} function is imported from the survey package.  
##' See \code{\link[survey]{svydesign}} documentation for details.
svydesign <- function(...) { survey::svydesign(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyglm}} function is imported from the survey package.  
##' See \code{\link[survey]{svyglm}} documentation for details.
svyglm <- function(...) { survey::svyglm(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svymean}} function is imported from the survey package.  
##' See \code{\link[survey]{svymean}} documentation for details.
svymean <- function(...) { survey::svymean(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyplot}} function is imported from the survey package.  
##' See \code{\link[survey]{svyplot}} documentation for details.
svyplot <- function(...) { survey::svyplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svytable}} function is imported from the survey package.  
##' See \code{\link[survey]{svytable}} documentation for details.
svytable <- function(...) { survey::svytable(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[ENmisc]{wtd.boxplot}} function is imported from the ENmisc package.  
##' See \code{\link[ENmisc]{wtd.boxplot}} documentation for details.
wtd.boxplot <- function(...) { ENmisc::wtd.boxplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.chi.sq}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.chi.sq}} documentation for details.
wtd.chi.sq <- function(...) { weights::wtd.chi.sq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.cor}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.cor}} documentation for details.
wtd.cor <- function(...) { weights::wtd.cor(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.hist}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.hist}} documentation for details.
wtd.hist <- function(...) { weights::wtd.hist(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{wtd.mean}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.mean}} documentation for details.
wtd.mean <- function(...) { Hmisc::wtd.mean(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{wtd.quantile}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.quantile}} documentation for details.
wtd.quantile <- function(...) { Hmisc::wtd.quantile(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.t.test}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.t.test}} documentation for details.
wtd.t.test <- function(...) { weights::wtd.t.test(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{wtd.var}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.var}} documentation for details.
wtd.var <- function(...) { Hmisc::wtd.var(...) }

==> poliscidata_2.2.2.tar.gz: poliscidata/R/available.imported.functions.r <==
##' @name available.imported.functions
##' @rdname available.imported.functions
##'
##' @title Imported Functions Made Available to Users
##' @param ... See source package help file for details on function usage.
##'
NULL

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{compmeans}} function is imported from descr package.  
##' See \code{\link[descr]{compmeans}} documentation for details.
compmeans <- function(...) { descr::compmeans(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{crosstab}} function is imported from the descr package.
##' See \code{\link[descr]{crosstab}} documentation for details.
crosstab <- function(...) { descr::crosstab(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{csv.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{csv.get}} documentation for details.
csv.get <- function(...) { Hmisc::csv.get(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{cut2}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{cut2}} documentation for details.
cut2 <- function(...) { Hmisc::cut2(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[plyr]{ddply}} function is imported from the plyr package.  
##' See \code{\link[plyr]{ddply}} documentation for details.
ddply <- function(...) { plyr::ddply(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{describe}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{describe}} documentation for details.
describe <- function(...) { Hmisc::describe(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[descr]{freq}} function is imported from the descr package. 
##' See \code{\link[descr]{freq}} documentation for details.
freq <- function(...) { descr::freq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[gplots]{plotmeans}} function is imported from the gplots package.  
##' See \code{\link[gplots]{plotmeans}} documentation for details.
plotmeans <- function(...) { gplots::plotmeans(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[car]{scatterplot}} function is imported from the car package.  
##' See \code{\link[car]{scatterplot}} documentation for details.
scatterplot <- function(...) { car::scatterplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{spss.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{spss.get}} documentation for details.
spss.get <- function(...) { Hmisc::spss.get(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[Hmisc]{stata.get}} function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{stata.get}} documentation for details.
stata.get <- function(...) { Hmisc::stata.get(...) }

##' @rdname available.imported.functions
##' @description The svyboxplot function is imported from the survey package.  
##' See \code{\link[survey]{svyhist}} documentation for details.
svyboxplot <- function(...) { survey::svyboxplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyby}} function is imported from the survey package.  
##' See \code{\link[survey]{svyby}} documentation for details.
svyby <- function(...) { survey::svyby(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svychisq}} function is imported from the survey package.  
##' See \code{\link[survey]{svychisq}} documentation for details.
svychisq <- function(...) { survey::svychisq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svydesign}} function is imported from the survey package.  
##' See \code{\link[survey]{svydesign}} documentation for details.
svydesign <- function(...) { survey::svydesign(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyglm}} function is imported from the survey package.  
##' See \code{\link[survey]{svyglm}} documentation for details.
svyglm <- function(...) { survey::svyglm(...) }

##' @rdname available.imported.functions
##' @description The svymean function is imported from the survey package.  
##' See \code{\link[survey]{surveysummary}} documentation for details.
svymean <- function(...) { survey::svymean(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svyplot}} function is imported from the survey package.  
##' See \code{\link[survey]{svyplot}} documentation for details.
svyplot <- function(...) { survey::svyplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[survey]{svytable}} function is imported from the survey package.  
##' See \code{\link[survey]{svytable}} documentation for details.
svytable <- function(...) { survey::svytable(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[ENmisc]{wtd.boxplot}} function is imported from the ENmisc package.  
##' See \code{\link[ENmisc]{wtd.boxplot}} documentation for details.
wtd.boxplot <- function(...) { ENmisc::wtd.boxplot(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.chi.sq}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.chi.sq}} documentation for details.
wtd.chi.sq <- function(...) { weights::wtd.chi.sq(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.cor}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.cor}} documentation for details.
wtd.cor <- function(...) { weights::wtd.cor(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.hist}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.hist}} documentation for details.
wtd.hist <- function(...) { weights::wtd.hist(...) }

##' @rdname available.imported.functions
##' @description The wtd.mean function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.stats}} documentation for details.
wtd.mean <- function(...) { Hmisc::wtd.mean(...) }

##' @rdname available.imported.functions
##' @description The wtd.quantile function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.stats}} documentation for details.
wtd.quantile <- function(...) { Hmisc::wtd.quantile(...) }

##' @rdname available.imported.functions
##' @description The \code{\link[weights]{wtd.t.test}} function is imported from the weights package.  
##' See \code{\link[weights]{wtd.t.test}} documentation for details.
wtd.t.test <- function(...) { weights::wtd.t.test(...) }

##' @rdname available.imported.functions
##' @description The wtd.var function is imported from the Hmisc package.  
##' See \code{\link[Hmisc]{wtd.stats}} documentation for details.
wtd.var <- function(...) { Hmisc::wtd.var(...) }
